# frozen_string_literal: false
require_relative 'android_device_name_generated'

module AndroidDeviceName
  include AndroidDeviceNameGenerated
  extend self

  def support_drop_for_android_device_name
    {
      GalaxyNote8: 'Galaxy Note 8'.freeze,
      GalaxyNote9: 'Galaxy Note 9'.freeze,
      GalaxyS8: 'Galaxy S8'.freeze,
      GalaxyS8Plus: 'Galaxy S8 Plus'.freeze,
      GalaxyS9Plus: 'Galaxy S9 Plus'.freeze,
    }
  end

  def pascal_android_device_name
    {
      Pixel3XL: 'AndroidDeviceName::Pixel_3_XL'.freeze,
      Pixel4: 'AndroidDeviceName::Pixel_4'.freeze,
      Pixel4XL: 'AndroidDeviceName::Pixel_4_XL'.freeze,
      GalaxyS9: 'AndroidDeviceName::Galaxy_S9'.freeze,
      GalaxyS10: 'AndroidDeviceName::Galaxy_S10'.freeze,
      GalaxyS10Plus: 'AndroidDeviceName::Galaxy_S10_Plus'.freeze,
      GalaxyNote10: 'AndroidDeviceName::Galaxy_Note_10'.freeze,
      GalaxyNote10Plus: 'AndroidDeviceName::Galaxy_Note_10_Plus'.freeze,
      GalaxyS20: 'AndroidDeviceName::Galaxy_S20'.freeze,
      GalaxyS20Plus: 'AndroidDeviceName::Galaxy_S20_Plus'.freeze,
      GalaxyS21: 'AndroidDeviceName::Galaxy_S21'.freeze,
      GalaxyS21Plus: 'AndroidDeviceName::Galaxy_S21_Plus'.freeze,
      GalaxyS21Ultra: 'AndroidDeviceName::Galaxy_S21_Ultra'.freeze,
    }
  end

  def const_missing(name)
    if pascal_android_device_name.include?(name)
      # deprecate_constant :... not allow to point to new version (
      puts "Warning: constant AndroidDeviceName::#{name} is deprecated use #{pascal_android_device_name[name]} instead."
      const_get(pascal_android_device_name[name])
    elsif support_drop_for_android_device_name.include?(name)
      raise Applitools::EyesIllegalArgument, 'support dropped for Android 9/10 specific devices, try to use more modern device'
    else
      super
    end
  end

  # now actual enum_values are in generated file
end
